@@ -5,7 +5,7 @@
 // Modified by:
 // Created:     29/10/2000
 // RCS-ID:      
-// Copyright:   (c) 2000 Mattia Barbon
+// Copyright:   (c) 2000-2001 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -13,7 +13,7 @@
 #ifndef _WXPERL_E_CBACK_H
 #define _WXPERL_E_CBACK_H
 
-class WXPLDLL wxPliEventCallback:public wxObject
+class wxPliEventCallback : public wxObject
 {
 public:
     wxPliEventCallback( SV* method, SV* self );
