@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h,v 1.53 2003/05/05 20:38:41 mbarbon Exp $
+// RCS-ID:      $Id: helpers.h,v 1.60 2003/08/22 22:21:57 mbarbon Exp $
 // Copyright:   (c) 2000-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -18,10 +18,13 @@
 #include <wx/gdicmn.h>
 
 // forward declare Wx_*Stream
-class wxInputStream;
-class wxOutputStream;
+class WXDLLEXPORT wxInputStream;
+class WXDLLEXPORT wxOutputStream;
+class WXDLLEXPORT wxEvtHandler;
+class WXDLLEXPORT wxClientDataContainer;
 typedef wxInputStream Wx_InputStream;
 typedef wxOutputStream Wx_OutputStream;
+typedef const char* PlClassName; // for typemap
 
 #include <stdarg.h>
 
@@ -120,6 +123,8 @@ const char* FUNCPTR( wxPli_cpp_class_2_perl )( const wxChar* className,
 // b - a boolean value
 // i - an 'int' value
 // l - a 'long' value
+// L - an 'unsigned long' value
+// d - a 'double' value
 // p - a char*
 // w - a wxChar*
 // P - a wxString*
@@ -135,10 +140,13 @@ void wxPli_push_args( pTHX_ SV*** stack, const char* argtypes, va_list &list );
 
 void* FUNCPTR( wxPli_sv_2_object )( pTHX_ SV* scalar, const char* classname );
 SV* FUNCPTR( wxPli_object_2_sv )( pTHX_ SV* var, wxObject* object );
+SV* FUNCPTR( wxPli_evthandler_2_sv )( pTHX_ SV* var, wxEvtHandler* evth );
 SV* FUNCPTR( wxPli_non_object_2_sv )( pTHX_ SV* var, void* data,
                                       const char* package );
 
 SV* FUNCPTR( wxPli_make_object )( void* object, const char* cname );
+SV* FUNCPTR( wxPli_create_evthandler )( pTHX_ wxEvtHandler* object,
+                                        const char* classn );
 
 bool FUNCPTR( wxPli_object_is_deleteable )( pTHX_ SV* object );
 void FUNCPTR( wxPli_object_set_deleteable )( pTHX_ SV* object,
@@ -164,6 +172,7 @@ int FUNCPTR( wxPli_av_2_intarray )( pTHX_ SV* avref, int** array );
 void wxPli_stringarray_push( pTHX_ const wxArrayString& strings );
 AV* wxPli_stringarray_2_av( pTHX_ const wxArrayString& strings );
 AV* wxPli_uchararray_2_av( pTHX_ const unsigned char* array, int count );
+AV* FUNCPTR( wxPli_objlist_2_av )( pTHX_ const wxList& objs );
 
 void wxPli_delete_argv( void* argv, bool unicode );
 int wxPli_get_args_argc_argv( void* argv, bool unicode );
@@ -208,9 +217,10 @@ SV* FUNCPTR( wxPliVirtualCallback_CallCallback )
 bool wxPli_match_arguments( pTHX_ const unsigned char prototype[],
                             size_t nproto, int required = -1,
                             bool allow_more = FALSE );
-bool wxPli_match_arguments_skipfirst(  pTHX_ const unsigned char prototype[],
-                                       size_t nproto, int required = -1,
-                                       bool allow_more = FALSE );
+bool FUNCPTR( wxPli_match_arguments_skipfirst )( pTHX_ const unsigned char p[],
+                                                 size_t nproto,
+                                                 int required = -1,
+                                                 bool allow_more = FALSE );
 
 #define WXPLI_BOOT_ONCE_( name, xs ) \
 extern "C" XS(wxPli_boot_##name); \
@@ -230,9 +240,18 @@ xs(boot_##name) \
 #  define WXPLI_BOOT_ONCE_EXP WXPLI_BOOT_ONCE
 #endif
 
+#if WXPERL_W_VERSION_GE( 2, 5, 0 )
+#define WXPLI_INIT_CLASSINFO()
+#else
+#define WXPLI_INIT_CLASSINFO() \
+  wxClassInfo::CleanUpClasses(); \
+  wxClassInfo::InitializeClasses()
+#endif
+
 struct wxPliHelpers
 {
     void* ( * m_wxPli_sv_2_object )( pTHX_ SV*, const char* );
+    SV* ( * m_wxPli_evthandler_2_sv )( pTHX_ SV* var, wxEvtHandler* evth );
     SV* ( * m_wxPli_object_2_sv )( pTHX_ SV*, wxObject* );
     SV* ( * m_wxPli_non_object_2_sv )( pTHX_ SV* , void*, const char* );
     SV* ( * m_wxPli_make_object )( void*, const char* );
@@ -265,10 +284,18 @@ struct wxPliHelpers
                                        const char* argtypes, ... );
     void ( * m_wxPli_attach_object )( pTHX_ SV* object, void* ptr );
     void* ( * m_wxPli_detach_object )( pTHX_ SV* object );
+    SV* ( * m_wxPli_create_evthandler )( pTHX_ wxEvtHandler* object,
+                                         const char* cln );
+    bool (* m_wxPli_match_arguments_skipfirst )( pTHX_ const unsigned char p[],
+                                                 size_t nproto,
+                                                 int required = -1,
+                                                 bool allow_more = FALSE );
+    AV* (* m_wxPli_objlist_2_av )( pTHX_ const wxList& objs );
 };
 
 #define DEFINE_PLI_HELPERS( name ) \
-wxPliHelpers name = { &wxPli_sv_2_object, &wxPli_object_2_sv, \
+wxPliHelpers name = { &wxPli_sv_2_object, \
+ &wxPli_evthandler_2_sv, &wxPli_object_2_sv, \
  &wxPli_non_object_2_sv, &wxPli_make_object, &wxPli_sv_2_wxpoint_test, \
  &wxPli_sv_2_wxpoint, \
  &wxPli_sv_2_wxsize, &wxPli_av_2_intarray, wxPli_stream_2_sv, \
@@ -277,7 +304,8 @@ wxPliHelpers name = { &wxPli_sv_2_object, &wxPli_object_2_sv, \
  &wxPli_object_is_deleteable, &wxPli_object_set_deleteable, &wxPli_get_class, \
  &wxPli_get_wxwindowid, &wxPli_av_2_stringarray, &wxPliInputStream_ctor, \
  &wxPli_cpp_class_2_perl, &wxPli_push_arguments, &wxPli_attach_object, \
- &wxPli_detach_object };
+ &wxPli_detach_object, &wxPli_create_evthandler, \
+ &wxPli_match_arguments_skipfirst, &wxPli_objlist_2_av }
 
 #if defined( WXPL_EXT ) && !defined( WXPL_STATIC ) && !defined(__WXMAC__)
 
@@ -285,6 +313,7 @@ wxPliHelpers name = { &wxPli_sv_2_object, &wxPli_object_2_sv, \
   SV* wxpli_tmp = get_sv( "Wx::_exports", 1 ); \
   wxPliHelpers* name = (wxPliHelpers*)(void*)SvIV( wxpli_tmp ); \
   wxPli_sv_2_object = name->m_wxPli_sv_2_object; \
+  wxPli_evthandler_2_sv = name->m_wxPli_evthandler_2_sv; \
   wxPli_object_2_sv = name->m_wxPli_object_2_sv; \
   wxPli_non_object_2_sv = name->m_wxPli_non_object_2_sv; \
   wxPli_make_object = name->m_wxPli_make_object; \
@@ -307,6 +336,11 @@ wxPliHelpers name = { &wxPli_sv_2_object, &wxPli_object_2_sv, \
   wxPli_push_arguments = name->m_wxPli_push_arguments; \
   wxPli_attach_object = name->m_wxPli_attach_object; \
   wxPli_detach_object = name->m_wxPli_detach_object; \
+  wxPli_create_evthandler = name->m_wxPli_create_evthandler; \
+  wxPli_match_arguments_skipfirst = name->m_wxPli_match_arguments_skipfirst; \
+  wxPli_objlist_2_av = name->m_wxPli_objlist_2_av; \
+  \
+  WXPLI_INIT_CLASSINFO();
 
 #else
 
@@ -323,9 +357,15 @@ class wxPliUserDataO : public wxObject
 {
 public:
     wxPliUserDataO( SV* data )
-        { dTHX; m_data = data ? newSVsv( data ) : 0; }
+    {
+        dTHX;
+        m_data = data ? newSVsv( data ) : NULL;
+    }
+
     ~wxPliUserDataO();
-public:
+
+    SV* GetData() { return m_data; }
+private:
     SV* m_data;
 };
 
@@ -354,6 +394,15 @@ typedef wxPliSelfRef* (* wxPliGetCallbackObjectFn)(wxObject* object);
 class wxPliClassInfo : public wxClassInfo
 {
 public:
+#if WXPERL_W_VERSION_GE( 2, 5, 0 )
+    wxPliClassInfo( wxChar *cName, const wxClassInfo *baseInfo1,
+                    const wxClassInfo *baseInfo2, 
+                    int sz, wxPliGetCallbackObjectFn fn )
+        :wxClassInfo( cName, baseInfo1, baseInfo2, sz, 0)
+    {
+        m_func = fn;
+    }
+#else
     wxPliClassInfo( wxChar *cName, wxChar *baseName1, wxChar *baseName2, 
                     int sz, wxPliGetCallbackObjectFn fn )
         :wxClassInfo( cName, baseName1, baseName2, sz, 0)
@@ -362,11 +411,12 @@ public:
             //FIXME//
             m_baseInfo1 = wxClassInfo::FindClass( baseName1 );
             //FIXME// this is an ugly hack!
-#if !defined( __WXMAC__ )
+#if 0 && !defined( __WXMAC__ )
             if( m_baseInfo1 == 0 )
                 croak( "ClassInfo initialization failed '%s'", baseName1 );
 #endif
         }
+#endif
 public:
     wxPliGetCallbackObjectFn m_func;
 };
@@ -385,12 +435,21 @@ public:\
 public:\
   wxPliVirtualCallback m_callback
 
+#if WXPERL_W_VERSION_GE( 2, 5, 0 )
+#define WXPLI_IMPLEMENT_DYNAMIC_CLASS(name, basename)                        \
+    wxPliSelfRef* wxPliGetSelfFor##name(wxObject* object)                    \
+        { return &((name *)object)->m_callback; }                            \
+    wxPliClassInfo name::sm_class##name((wxChar *) wxT(#name),               \
+        &sm_class##basename, NULL, (int) sizeof(name),                       \
+        (wxPliGetCallbackObjectFn) wxPliGetSelfFor##name);
+#else
 #define WXPLI_IMPLEMENT_DYNAMIC_CLASS(name, basename) \
 wxPliSelfRef* wxPliGetSelfFor##name(wxObject* object) \
   { return &((name *)object)->m_callback; }\
 wxPliClassInfo name::sm_class##name((wxChar *) wxT(#name), \
   (wxChar *) wxT(#basename), (wxChar *) NULL, (int) sizeof(name), \
   (wxPliGetCallbackObjectFn) wxPliGetSelfFor##name);
+#endif
 
 #define WXPLI_DEFAULT_CONSTRUCTOR_NC( name, packagename, incref ) \
     name( const char* package )                                   \
@@ -541,7 +600,7 @@ typedef SV SV_null; // equal to SV except that maps C++ 0 <-> Perl undef
 
 #endif // __CPP_HELPERS_H
 
-#if defined( _WX_WINDOW_H_BASE_ ) || defined( _WX_CLNTDATAH__ )
+#if defined( _WX_CLNTDATAH__ )
 #ifndef __CPP_HELPERS_H_UDCD
 #define __CPP_HELPERS_H_UDCD
 
@@ -549,9 +608,15 @@ class wxPliUserDataCD : public wxClientData
 {
 public:
     wxPliUserDataCD( SV* data )
-        { dTHX; m_data = data ? newSVsv( data ) : 0; }
+    {
+        dTHX;
+        m_data = data ? newSVsv( data ) : NULL;
+    }
+
     ~wxPliUserDataCD();
-public:
+
+    SV* GetData() { return m_data; }
+private:
     SV* m_data;
 };
 
@@ -566,16 +631,22 @@ class wxPliTreeItemData:public wxTreeItemData
 {
 public:
     wxPliTreeItemData( SV* data )
-        { dTHX; m_data = data ? newSVsv( data ) : 0; }
+        : m_data( NULL )
+    {
+        SetData( data );
+    }
+
     ~wxPliTreeItemData()
-        { dTHX; if( m_data ) SvREFCNT_dec( m_data ); }
+    {
+        SetData( NULL );
+    }
 
     void SetData( SV* data )
     {
         dTHX;
         if( m_data )
             SvREFCNT_dec( m_data );
-        m_data = data ? newSVsv( data ) : 0;
+        m_data = data ? newSVsv( data ) : NULL;
     }
 public:
     SV* m_data;
