@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     21/ 9/2002
-// RCS-ID:      $Id: wxapi.h,v 1.5 2003/05/02 20:27:53 mbarbon Exp $
+// RCS-ID:      $Id: wxapi.h,v 1.7 2003/08/02 21:08:55 mbarbon Exp $
 // Copyright:   (c) 2002-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -34,6 +34,14 @@ WXPL_EXTERN_C_START
 #include <XSUB.h>
 WXPL_EXTERN_C_END
 
+#if WXPERL_P_VERSION_GE( 5, 9, 0 ) || WXPERL_P_VERSION_GE( 5, 8, 1 )
+
+// XXX this is an hack
+#undef assert_not_ROK
+#define assert_not_ROK(sv)
+
+#endif
+
 #undef bool
 #undef Move
 #undef Copy
