@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     21/ 3/2001
-// RCS-ID:      $Id: ht_constants.cpp,v 1.6 2003/05/05 20:38:42 mbarbon Exp $
+// RCS-ID:      $Id: ht_constants.cpp,v 1.7 2003/08/02 20:55:17 mbarbon Exp $
 // Copyright:   (c) 2001, 2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -41,6 +41,10 @@ double html_constant( const char* name, int arg )
         r( wxHF_ICONS_BOOK );
         r( wxHF_ICONS_BOOK_CHAPTER );
         r( wxHF_ICONS_FOLDER );
+
+#if WXPERL_W_VERSION_GE( 2, 5, 0 )
+        r( wxHW_NO_SELECTION );
+#endif
         break;
     case 'P':
         r( wxPAGE_ODD );
